fsmonitor

package
v0.0.0-...-f76d60a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 10, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Overview

Package fsmonitor monitors change events in the specified directory. The detected Event are sent as messages to subscribers who have subscribed to the Topic.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Event

type Event struct {
	Path string
	Type Type
}

type Monitor

type Monitor struct {
	// contains filtered or unexported fields
}

func New

func New(ctx context.Context, dir string, opts ...Option) (*Monitor, error)

func (*Monitor) Close

func (m *Monitor) Close()

func (*Monitor) Topic

func (m *Monitor) Topic() *pubsub.Topic[Event]

type Option

type Option interface {
	// contains filtered or unexported methods
}

func WithExcludeDirs

func WithExcludeDirs(dirs ...string) Option

type Type

type Type = fsnotify.Op

Jump to