gitfunc

package
v0.0.0-...-db090c8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 15, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Package gitfunc provides wrappers for the functions of go-git that iview uses.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DirStatus

func DirStatus(dir string) (git.Status, error)

DirStatus returns git.Status limited to the specified directory. If the specified directory is not under git control, it returns git.ErrRepositoryNotExists.

func Worktree

func Worktree(dir string) (*git.Worktree, error)

Worktree returns the *git.Worktree of the specified directory if it is under git control.

Types

This section is empty.

Jump to